@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -23,6 +23,7 @@ from mailman.app.lifecycle import create_list
 from mailman.app.membership import add_member
 from mailman.handlers import dmarc
 from mailman.interfaces.mailinglist import DMARCMitigateAction, ReplyToMunging
+from mailman.interfaces.member import MemberRole
 from mailman.interfaces.subscriptions import RequestRecord
 from mailman.testing.helpers import specialized_message_from_string as mfs
 from mailman.testing.layers import ConfigLayer
@@ -270,6 +271,41 @@ Some things to say.
 Content-Type: text/html; charset="us-ascii"
 Content-Transfer-Encoding: 7bit
 
+<html><head></head><body>Some things to say.</body></html>
+--=====abc==--
+""")
+
+    def test_action_munge_from_nonmember_display_name_in_list(self):
+        self._mlist.dmarc_mitigate_action = DMARCMitigateAction.munge_from
+        add_member(
+            self._mlist,
+            RequestRecord('anne@example.com', 'Anna Banana'),
+            role=MemberRole.nonmember
+            )
+        msgdata = {'dmarc': True}
+        msg = mfs(self._text)
+        dmarc.process(self._mlist, msg, msgdata)
+        self.assertMultiLineEqual(msg.as_string(), """\
+To: ant@example.com
+Subject: A subject
+X-Mailman-Version: X.Y
+Message-ID: <alpha@example.com>
+Date: Fri, 1 Jan 2016 00:00:01 +0000
+Another-Header: To test removal in wrapper
+MIME-Version: 1.0
+Content-Type: multipart/alternative; boundary="=====abc=="
+From: Anna Banana via Ant <ant@example.com>
+Reply-To: anne@example.com
+
+--=====abc==
+Content-Type: text/plain; charset="us-ascii"
+Content-Transfer-Encoding: 7bit
+
+Some things to say.
+--=====abc==
+Content-Type: text/html; charset="us-ascii"
+Content-Transfer-Encoding: 7bit
+
 <html><head></head><body>Some things to say.</body></html>
 --=====abc==--
 """)
@@ -408,6 +444,58 @@ Content-Disposition: inline
 
 """ + self._text)
 
+    def test_wrap_message_cc_with_reply_to(self):
+        self._mlist.dmarc_mitigate_action = DMARCMitigateAction.wrap_message
+        self._mlist.reply_goes_to_list = ReplyToMunging.point_to_list
+        msgdata = {'dmarc': True}
+        msg = mfs(self._text)
+        msg['Reply-To'] = 'user@example.com'
+        orig_msg = msg.as_string()
+        dmarc.process(self._mlist, msg, msgdata)
+        # We can't predict the Message-ID in the wrapper so delete it, but
+        # ensure we have one.
+        self.assertIsNotNone(msg.get('message-id'))
+        del msg['message-id']
+        self.assertMultiLineEqual(msg.as_string(), """\
+To: ant@example.com
+Subject: A subject
+X-Mailman-Version: X.Y
+Date: Fri, 1 Jan 2016 00:00:01 +0000
+MIME-Version: 1.0
+From: anne--- via Ant <ant@example.com>
+Cc: anne@example.com
+Reply-To: user@example.com
+Content-Type: message/rfc822
+Content-Disposition: inline
+
+""" + orig_msg)
+
+    def test_wrap_message_reply_to_with_cc(self):
+        self._mlist.dmarc_mitigate_action = DMARCMitigateAction.wrap_message
+        self._mlist.reply_goes_to_list = ReplyToMunging.no_munging
+        msgdata = {'dmarc': True}
+        msg = mfs(self._text)
+        msg['Cc'] = 'user@example.com'
+        orig_msg = msg.as_string()
+        dmarc.process(self._mlist, msg, msgdata)
+        # We can't predict the Message-ID in the wrapper so delete it, but
+        # ensure we have one.
+        self.assertIsNotNone(msg.get('message-id'))
+        del msg['message-id']
+        self.assertMultiLineEqual(msg.as_string(), """\
+To: ant@example.com
+Subject: A subject
+X-Mailman-Version: X.Y
+Date: Fri, 1 Jan 2016 00:00:01 +0000
+MIME-Version: 1.0
+From: anne--- via Ant <ant@example.com>
+Reply-To: anne@example.com
+Cc: user@example.com
+Content-Type: message/rfc822
+Content-Disposition: inline
+
+""" + orig_msg)
+
     def test_rfc2047_encoded_from(self):
         self._mlist.dmarc_mitigate_action = DMARCMitigateAction.munge_from
         msgdata = {'dmarc': True}
