@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2007-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -25,12 +25,18 @@ from mailman.database.model import Model
 from mailman.database.transaction import dbconnection
 from mailman.database.types import SAUnicode, SAUnicodeXL
 from mailman.interfaces.pending import (
-    IPendable, IPended, IPendedKeyValue, IPendings)
+    IPendable,
+    IPended,
+    IPendedKeyValue,
+    IPendings,
+)
+from mailman.interfaces.workflow import IWorkflowStateManager
 from mailman.utilities.datetime import now
 from mailman.utilities.uid import TokenFactory
 from public import public
-from sqlalchemy import Column, DateTime, ForeignKey, Index, Integer, and_
+from sqlalchemy import and_, Column, DateTime, ForeignKey, Index, Integer
 from sqlalchemy.orm import aliased, relationship
+from zope.component import getUtility
 from zope.interface import implementer
 from zope.interface.verify import verifyObject
 
@@ -86,7 +92,10 @@ class Pendings:
         verifyObject(IPendable, pendable)
         # Calculate the token and the lifetime.
         if lifetime is None:
-            lifetime = as_timedelta(config.mailman.pending_request_life)
+            if pendable.get('token_owner', None) == 'moderator':
+                lifetime = as_timedelta(config.mailman.moderator_request_life)
+            else:
+                lifetime = as_timedelta(config.mailman.pending_request_life)
         for attempts in range(3):
             token = token_factory.new()
             # In practice, we'll never get a duplicate, but we'll be anal
@@ -123,10 +132,11 @@ class Pendings:
         # Token can come in as a unicode, but it's stored in the database as
         # bytes.  They must be ascii.
         pendings = store.query(Pended).filter_by(token=str(token))
-        if pendings.count() == 0:
+        pendings_count = pendings.count()
+        if pendings_count == 0:
             return None
-        assert pendings.count() == 1, (
-            'Unexpected token count: {}'.format(pendings.count()))
+        assert pendings_count == 1, (
+            'Unexpected token count: {}'.format(pendings_count))
         pending = pendings[0]
         pendable = UnpendedPendable()
         # Iterate on PendedKeyValue entries that are associated with the
@@ -143,6 +153,8 @@ class Pendings:
             pendable[keyvalue.key] = value
         if expunge:
             store.delete(pending)
+            # Discard associated workflow if any.
+            getUtility(IWorkflowStateManager).discard(token)
         return pendable
 
     @dbconnection
@@ -153,7 +165,9 @@ class Pendings:
                 store.delete(pending)
 
     @dbconnection
-    def _query(self, store, mlist, pend_type, token_owner):
+    def _query(
+        self, store, mlist, pend_type, token_owner, held_msgid
+    ):
         query = store.query(Pended)
         if mlist is not None:
             pkv_alias_mlist = aliased(PendedKeyValue)
@@ -161,6 +175,12 @@ class Pendings:
                 pkv_alias_mlist.key == 'list_id',
                 pkv_alias_mlist.value == json.dumps(mlist.list_id)
                 ))
+        if held_msgid is not None:
+            pkv_alias_held_msg = aliased(PendedKeyValue)
+            query = query.join(pkv_alias_held_msg).filter(and_(
+                pkv_alias_held_msg.key == '_mod_message_id',
+                pkv_alias_held_msg.value == json.dumps(held_msgid)
+                ))
         if pend_type is not None:
             pkv_alias_type = aliased(PendedKeyValue)
             query = query.join(pkv_alias_type).filter(and_(
@@ -175,8 +195,15 @@ class Pendings:
                 ))
         return query
 
-    def find(self, mlist=None, pend_type=None, confirm=True, token_owner=None):
-        query = self._query(mlist, pend_type, token_owner)
+    def find(
+        self,
+        mlist=None,
+        pend_type=None,
+        confirm=True,
+        token_owner=None,
+        held_msgid=None,
+    ):
+        query = self._query(mlist, pend_type, token_owner, held_msgid)
         for pending in query:
             pendable = (self.confirm(pending.token, expunge=False)
                         if confirm else None)
@@ -187,6 +214,8 @@ class Pendings:
         for pending in store.query(Pended).all():
             yield pending.token, self.confirm(pending.token, expunge=False)
 
-    def count(self, mlist=None, pend_type=None, token_owner=None):
-        query = self._query(mlist, pend_type, token_owner)
+    def count(
+        self, mlist=None, pend_type=None, token_owner=None, held_msgid=None
+    ):
+        query = self._query(mlist, pend_type, token_owner, held_msgid)
         return query.count()
