@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2007-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -98,6 +98,7 @@ class AbstractRoster:
     def _get_all_memberships(self, store, email):
         # Avoid circular imports.
         from mailman.model.user import User
+
         # Here's a query that finds all members subscribed with an explicit
         # email address.
         members_a = store.query(Member).filter(
@@ -166,7 +167,7 @@ class OwnerRoster(AbstractRoster):
 
 @public
 class ModeratorRoster(AbstractRoster):
-    """Return all the owners of a list."""
+    """Return all the moderators of a list."""
 
     name = 'moderator'
     role = MemberRole.moderator
@@ -188,12 +189,19 @@ class AdministratorRoster(AbstractRoster):
     @dbconnection
     def get_member(self, store, email):
         """See `IRoster`."""
-        return store.query(Member).filter(
+        members = store.query(Member).filter(
             Member.list_id == self._mlist.list_id,
             or_(Member.role == MemberRole.moderator,
                 Member.role == MemberRole.owner),
             Address.email == email,
-            Member.address_id == Address.id).one_or_none()
+            Member.address_id == Address.id).all()
+        if len(members) == 0:
+            return None
+        for member in members:
+            if member.role == MemberRole.owner:
+                return member
+        assert len(members) == 1, 'mlist.administrators has too many members'
+        return members[0]
 
 
 @public
