@@ -1,4 +1,4 @@
-# Copyright (C) 2006-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2006-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -30,6 +30,7 @@ class OwnerPipeline(BasePipeline):
     description = _('The built-in owner pipeline.')
 
     _default_handlers = (
+        'cleanse-dkim',
         'owner-recipients',
         'to-outgoing',
         )
@@ -61,6 +62,8 @@ class PostingPipeline(BasePipeline):
         # All decoration is now done in delivery.
         # 'decorate',
         'dmarc',
-        'arc-sign',
+        # Message decoration in delivery can break an arc signature, so sign
+        # in delivery after decorating.
+        # 'arc-sign',
         'to-outgoing',
         )
