@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2011-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -32,8 +32,11 @@ from mailman.interfaces.usermanager import IUserManager
 from mailman.model.mailinglist import AcceptableAlias
 from mailman.runners.digest import DigestRunner
 from mailman.testing.helpers import (
-    call_api, get_queue_messages, make_testable_runner,
-    specialized_message_from_string as mfs)
+    call_api,
+    get_queue_messages,
+    make_testable_runner,
+    specialized_message_from_string as mfs,
+)
 from mailman.testing.layers import RESTLayer
 from mailman.utilities.datetime import now as right_now
 from urllib.error import HTTPError
@@ -127,6 +130,29 @@ class TestFindLists(unittest.TestCase):
         mlist = json['entries'][0]
         self.assertEqual(mlist['list_id'], 'test2.example.com')
 
+    def test_find_lists_with_subscriber_as_nonmember(self):
+        # Test GET /lists/find with a valid subscriber, but nonmember
+        with transaction():
+            list2 = create_list('test2@example.com')
+            create_list('test3@example.com')
+            anne_addr = self._user_manager.create_address('anne@example.com')
+            self._mlist.subscribe(anne_addr, role=MemberRole.nonmember)
+            list2.subscribe(anne_addr, role=MemberRole.moderator)
+        # With role=nonmember, only one list will be returned.
+        json, response = call_api(
+            'http://localhost:9001/3.1/lists/find',
+            {'subscriber': 'anne@example.com', 'role': 'nonmember'})
+        self.assertEqual(json['total_size'], 1)
+        mlist = json['entries'][0]
+        self.assertEqual(mlist['list_id'], 'test.example.com')
+        # Without role, we should get 2nd list.
+        json, response = call_api(
+            'http://localhost:9001/3.1/lists/find',
+            {'subscriber': 'anne@example.com'})
+        self.assertEqual(json['total_size'], 1)
+        mlist = json['entries'][0]
+        self.assertEqual(mlist['list_id'], 'test2.example.com')
+
     def test_find_lists_with_bad_role(self):
         with transaction():
             self._mlist.subscribe(self.address)
@@ -859,6 +885,8 @@ class TestListTemplates(unittest.TestCase):
                 'list:admin:notice:subscribe': '',
                 'list:admin:notice:unrecognized': '',
                 'list:admin:notice:unsubscribe': '',
+                'list:admin:notice:pending': '',
+                'list:admin:notice:increment': '',
                 'list:admin:notice:disable': '',
                 'list:admin:notice:removal': '',
                 'list:member:digest:footer': '',
