@@ -1,4 +1,4 @@
-# Copyright (C) 1998-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -53,7 +53,7 @@ class CommandFinder:
         self.command_lines = []
         self.ignored_lines = []
         self.processed_lines = []
-        self.send_response = True
+        results.send_response = True
         # Depending on where the message was destined to, add some implicit
         # commands.  For example, if this was sent to the -join or -leave
         # addresses, it's the same as if 'join' or 'leave' commands were sent
@@ -62,12 +62,12 @@ class CommandFinder:
         subaddress = msgdata.get('subaddress')
         if subaddress == 'join':
             self.command_lines.append('join')
-            self.send_response = False
+            results.send_response = False
             is_address_command = True
         elif subaddress == 'leave':
             self.command_lines.append('leave')
             is_address_command = True
-            self.send_response = False
+            results.send_response = False
         elif subaddress == 'confirm':
             # match with re.DOTALL in case header is folded.
             mo = re.match(config.mta.verp_confirm_regexp,
@@ -75,7 +75,7 @@ class CommandFinder:
             if mo:
                 self.command_lines.append('confirm ' + mo.group('cookie'))
                 is_address_command = True
-                self.send_response = False
+                results.send_response = False
         # Stop processing if the address already contained a valid command
         if is_address_command:
             return
@@ -83,8 +83,8 @@ class CommandFinder:
         raw_subject = msg.get('subject', '')
         try:
             subject = str(make_header(decode_header(raw_subject)))
-            # Mail commands must be ASCII.
-            self.command_lines.append(subject.encode('us-ascii'))
+            # Mail commands must be ASCII, so strip non-ascii.
+            self.command_lines.append(subject.encode('us-ascii', 'ignore'))
         except (HeaderParseError, UnicodeError, LookupError):
             # The Subject header was unparseable or not ASCII.  If the raw
             # subject is a unicode object, convert it to ASCII ignoring all
@@ -104,9 +104,11 @@ class CommandFinder:
         if part is None:
             # There was no text/plain part to be found.
             return
-        body = part.get_payload()
+        body = part.get_payload(decode=True)
         # text/plain parts better have string payloads.
-        assert isinstance(body, (bytes, str)), 'Non-string decoded payload'
+        assert body is not None, 'Non-text payload'
+        body = body.decode(part.get_content_charset('us-ascii'),
+                           errors='replace')
         lines = body.splitlines()
         # Use no more lines than specified
         max_lines = int(config.mailman.email_commands_max_lines)
@@ -138,6 +140,7 @@ class Results:
     def __init__(self, charset='us-ascii'):
         self._output = StringIO()
         self.charset = charset
+        self.send_response = True
         print(_("""\
 The results of your email command are provided below.
 """), file=self._output)
@@ -183,13 +186,15 @@ class CommandRunner(Runner):
         # Include just a few key pieces of information from the original: the
         # sender, date, and message id.
         print(_('- Original message details:'), file=results)
-        subject = msg.get('subject', 'n/a')                      # noqa: F841
+        subject = str(make_header(decode_header(                 # noqa: F841
+            msg.get('subject', 'n/a'))))
         date = msg.get('date', 'n/a')                            # noqa: F841
-        from_ = msg.get('from', 'n/a')                           # noqa: F841
-        print(_('    From: $from_'), file=results)
-        print(_('    Subject: $subject'), file=results)
-        print(_('    Date: $date'), file=results)
-        print(_('    Message-ID: $message_id'), file=results)
+        from_ = str(make_header(decode_header(                   # noqa: F841
+            msg.get('from', 'n/a'))))
+        print(_('    From: ${from_}'), file=results)
+        print(_('    Subject: ${subject}'), file=results)
+        print(_('    Date: ${date}'), file=results)
+        print(_('    Message-ID: ${message_id}'), file=results)
         print(_('\n- Results:'), file=results)
         finder = CommandFinder(msg, msgdata, results)
         for parts in finder:
@@ -204,7 +209,7 @@ class CommandRunner(Runner):
                 command_name = parts.pop(0)
                 command = config.commands.get(command_name)
             if command is None:
-                print(_('No such command: $command_name'), file=results)
+                print(_('No such command: ${command_name}'), file=results)
             else:
                 status = command.process(
                     mlist, msg, msgdata, parts, results)
@@ -213,7 +218,7 @@ class CommandRunner(Runner):
                 if status == ContinueProcessing.no:
                     break
         # All done. If we don't need to send response, return.
-        if not finder.send_response:
+        if not results.send_response:
             return
         # Strip blank lines and send the response.
         lines = [line.strip() for line in finder.command_lines if line]
