@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2008-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -25,13 +25,14 @@
 # get rid of the layers and use something like testresources or some such.
 
 import os
+import ssl
 import sys
 import shutil
 import logging
 import datetime
 import tempfile
 
-from importlib_resources import read_text
+from importlib.resources import files, read_text
 from lazr.config import as_boolean
 from mailman.config import config
 from mailman.core import initialize
@@ -40,8 +41,16 @@ from mailman.core.logging import get_handler
 from mailman.database.transaction import transaction
 from mailman.interfaces.domain import IDomainManager
 from mailman.testing.helpers import (
-    TestableMaster, get_lmtp_client, reset_the_world, wait_for_webservice)
-from mailman.testing.mta import ConnectionCountingController
+    get_lmtp_client,
+    reset_the_world,
+    TestableMaster,
+    wait_for_webservice,
+)
+from mailman.testing.mta import (
+    ConnectionCountingController,
+    ConnectionCountingSSLController,
+    ConnectionCountingSTARTTLSController,
+)
 from mailman.utilities.string import expand
 from public import public
 from textwrap import dedent
@@ -153,12 +162,16 @@ class ConfigLayer(MockAndMonkeyLayer):
             # debugging because it's just too verbose.  Unfortunately, if you
             # do want that level of debugging you currently have to manually
             # modify this conditional.
-            if cls.stderr and sub_name != 'database':
+            if sub_name != 'database':
                 test_config += expand(dedent("""
                 [logging.$name]
-                propagate: yes
-                level: debug
-                """), None, dict(name=sub_name, path=path))
+                path: $path
+                $extra_verbose
+                """), None, dict(name=sub_name, path=path,
+                                 extra_verbose=dedent("""
+                                     propagate: yes
+                                     level: debug
+                                     """) if cls.stderr else ""))
         # The root logger will already have a handler, but it's not the right
         # handler.  Remove that and set our own.
         if cls.stderr:
@@ -257,6 +270,112 @@ class SMTPLayer(ConfigLayer):
         cls.smtpd.clear()
 
 
+@public
+class SMTPSLayer(ConfigLayer):
+    """Layer for starting, stopping, and accessing a test SMTPS server."""
+
+    smtpd = None
+
+    @classmethod
+    def setUp(cls):
+        assert cls.smtpd is None, 'Layer already set up'
+        # Use a different port than the SMTP layer, since that one might
+        # still be in use.
+        config.push('smtps', """
+        [mta]
+        smtp_port: 9465
+        smtp_secure_mode: smtps
+        """)
+        test_cert_path = files('mailman.testing') / 'ssl_test_cert.crt'
+        test_key_path = files('mailman.testing') / 'ssl_test_key.key'
+
+        client_context = ssl.create_default_context()
+        client_context.load_verify_locations(cafile=test_cert_path)
+
+        server_context = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
+        server_context.load_cert_chain(test_cert_path, test_key_path)
+
+        host = config.mta.smtp_host
+        port = int(config.mta.smtp_port)
+
+        cls.smtpd = ConnectionCountingSSLController(
+            host, port,
+            client_context=client_context,
+            server_context=server_context)
+        cls.smtpd.start()
+
+    @classmethod
+    def testSetUp(cls):
+        # Make sure we don't call our superclass's testSetUp(), otherwise the
+        # example.com domain will get added twice.
+        pass
+
+    @classmethod
+    def testTearDown(cls):
+        cls.smtpd.reset()
+        cls.smtpd.clear()
+
+    @classmethod
+    def tearDown(cls):
+        assert cls.smtpd is not None, 'Layer not set up'
+        cls.smtpd.clear()
+        cls.smtpd.stop()
+        config.pop('smtps')
+
+
+@public
+class STARTTLSLayer(ConfigLayer):
+    """Layer for starting and stopping a test SMTP server with STARTTLS."""
+
+    smtpd = None
+
+    @classmethod
+    def setUp(cls):
+        assert cls.smtpd is None, 'Layer already set up'
+        # Use a different port than the SMTP and SMTPS layers, since that one
+        # might still be in use.
+        config.push('starttls', """
+        [mta]
+        smtp_port: 9587
+        smtp_secure_mode: starttls
+        """)
+        test_cert_path = files('mailman.testing') / 'ssl_test_cert.crt'
+        test_key_path = files('mailman.testing') / 'ssl_test_key.key'
+
+        client_context = ssl.create_default_context()
+        client_context.load_verify_locations(cafile=test_cert_path)
+
+        server_context = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
+        server_context.load_cert_chain(test_cert_path, test_key_path)
+
+        host = config.mta.smtp_host
+        port = int(config.mta.smtp_port)
+
+        cls.smtpd = ConnectionCountingSTARTTLSController(
+            host, port,
+            client_context=client_context,
+            server_context=server_context)
+        cls.smtpd.start()
+
+    @classmethod
+    def testSetUp(cls):
+        # Make sure we don't call our superclass's testSetUp(), otherwise the
+        # example.com domain will get added twice.
+        pass
+
+    @classmethod
+    def testTearDown(cls):
+        cls.smtpd.reset()
+        cls.smtpd.clear()
+
+    @classmethod
+    def tearDown(cls):
+        assert cls.smtpd is not None, 'Layer not set up'
+        cls.smtpd.clear()
+        cls.smtpd.stop()
+        config.pop('starttls')
+
+
 @public
 class LMTPLayer(ConfigLayer):
     """Layer for starting, stopping, and accessing a test LMTP server."""
@@ -291,6 +410,7 @@ class RESTLayer(SMTPLayer):
     """Layer for starting, stopping, and accessing the test REST layer."""
 
     server = None
+    stderr = True
 
     @classmethod
     def setUp(cls):
