@@ -21,11 +21,11 @@ import os
 import sys
 
 from contextlib import ExitStack
+from importlib.resources import files
 from itertools import product
 from mailman.config import config
 from mailman.core.constants import system_preferences
 from mailman.interfaces.errors import MailmanError
-from mailman.utilities.filesystem import path
 from public import public
 
 
@@ -114,7 +114,8 @@ def search(resources, template_file, mlist=None, language=None):
         languages.append(language)
     languages.reverse()
     # The non-language qualified $template_dir paths in search order.
-    templates_dir = str(resources.enter_context(path('mailman', 'templates')))
+    templates_dir = str(resources.enter_context(
+        files('mailman').joinpath('templates')))
     paths = [templates_dir, os.path.join(config.TEMPLATE_DIR, 'site')]
     if mlist is not None:
         # Don't forget these are in REVERSE search order!
